# yahpogym 1.0.2
* Fixes to make yahpogym work with new bbotk and paradox version 1.0.0.

# yahpogym 1.0.1
* Minor usability fixes and updates to documentation.

# yahpogym 1.0.0
* First major release together with publication.
